<?php

namespace LakeDrops\ComposerScripts;

use Composer\Script\Event;
use LakeDrops\Component\Composer\BaseHandler;
use LakeDrops\Component\Composer\Utils;

/**
 * Class Handler.
 *
 * @package LakeDrops\ComposerScripts
 */
class Handler extends BaseHandler {

  /**
   * Update scripts of all LakeDrops plugins.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   */
  public function updateScripts(Event $event) {

    // We only do the fancy stuff for developers.
    if (!$event->isDevMode()) {
      return;
    }

    $settings = new Utils($this->composer);
    $scripts = $settings->getSection('scripts');
    $scriptDescriptions = $settings->getSubSection('extra', 'scripts-description');
    $installationManager = $this->composer->getInstallationManager();
    foreach ($this->composer->getRepositoryManager()->getLocalRepository()->search('lakedrops/*') as $pkg) {
      $pluginRoot = $installationManager->getInstallPath($this->getPackage($pkg['name']));
      $pluginSettings = new Utils($this->composer, $pluginRoot);
      foreach ($pluginSettings->getSubSubSection('extra', 'lakedrops', 'scripts') as $name => $script) {
        $scripts[$name] = $script['callback'];
        $scriptDescriptions[$name] = $script['description'];
      }
    }
    foreach ($this->defaults() as $key => $default) {
      $scripts[$key] = $default['script'];
      $scriptDescriptions[$key] = $default['description'];
    }

    $settings->setSection('scripts', $scripts);
    $settings->setSubSection('extra', 'scripts-description', $scriptDescriptions);
    $settings->write();
  }

  /**
   * Provides an array of default scripts for Drupal projects.
   *
   * @return array
   */
  protected function defaults() {
    return [
      'phpcs' => [
        'script' => 'phpcs --standard=DrupalPractice $(pwd)/web/modules/custom/ $(pwd)/web/profiles/custom/ $(pwd)/web/themes/custom/',
        'description' => 'Run PHP Code Sniffer on custom code',
      ],
      'phpunit:test' => [
        'script' => 'vendor/bin/phpunit --configuration $(pwd)/tests/phpunit.xml.dist',
        'description' => 'Run PHPUnit tests on custom code',
      ],
      'phpunit:list:suites' => [
        'script' => 'vendor/bin/phpunit --configuration $(pwd)/tests/phpunit.xml.dist --list-suites',
        'description' => 'List all PHPUnit test suites for custom code',
      ],
      'phpunit:list:groups' => [
        'script' => 'vendor/bin/phpunit --configuration $(pwd)/tests/phpunit.xml.dist --list-groups',
        'description' => 'List all PHPUnit test groups from custom code',
      ],
    ];
  }
}
